package
Version:
v0.9.4
Opens a new window with list of versions in this module.
Published: Jun 5, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Manager is the bus instance manager, which subscribes plugins to events emitted.
func (b *Bus) Initialize()
func (b *Bus) LoadProviders()
Source Files
¶
Click to show internal directories.
Click to hide internal directories.